@@ -1,9 +1,10 @@
 import os
 from datetime import datetime, timedelta
 
-from SRT import SRT, passenger
 from PyInquirer import prompt
 
+from SRT import SRT
+
 VERBOSE = os.environ.get("DEBUG") is not None
 
 SRT_STATIONS = (
