@@ -1,9 +1,11 @@
-from datetime import datetime, timedelta
 import re
-import requests
+from datetime import datetime, timedelta
+
+import requests  # type: ignore
+
 from .constants import STATION_CODE
-from .errors import *
-from .passenger import *
+from .errors import SRTError, SRTLoginError, SRTNotLoggedInError, SRTResponseError
+from .passenger import Adult, Passenger
 from .reservation import SRTReservation, SRTTicket
 from .response_data import SRTResponseData
 from .train import SRTTrain
@@ -19,22 +21,23 @@ SRT_MOBILE = "{scheme}://{host}:{port}".format(
     scheme=SCHEME, host=SRT_HOST, port=SRT_PORT
 )
 
-SRT_MAIN = "{}/main/main.do".format(SRT_MOBILE)
-SRT_LOGIN = "{}/apb/selectListApb01080_n.do".format(SRT_MOBILE)
-SRT_LOGOUT = "{}/login/loginOut.do".format(SRT_MOBILE)
-SRT_SEARCH_SCHEDULE = "{}/ara/selectListAra10007_n.do".format(SRT_MOBILE)
-SRT_RESERVE = "{}/arc/selectListArc05013_n.do".format(SRT_MOBILE)
-SRT_TICKETS = "{}/atc/selectListAtc14016_n.do".format(SRT_MOBILE)
-SRT_TICKET_INFO = "{}/ard/selectListArd02017_n.do?".format(SRT_MOBILE)
-SRT_CANCEL = "{}/ard/selectListArd02045_n.do".format(SRT_MOBILE)
+SRT_MAIN = f"{SRT_MOBILE}/main/main.do"
+SRT_LOGIN = f"{SRT_MOBILE}/apb/selectListApb01080_n.do"
+SRT_LOGOUT = f"{SRT_MOBILE}/login/loginOut.do"
+SRT_SEARCH_SCHEDULE = f"{SRT_MOBILE}/ara/selectListAra10007_n.do"
+SRT_RESERVE = f"{SRT_MOBILE}/arc/selectListArc05013_n.do"
+SRT_TICKETS = f"{SRT_MOBILE}/atc/selectListAtc14016_n.do"
+SRT_TICKET_INFO = f"{SRT_MOBILE}/ard/selectListArd02017_n.do?"
+SRT_CANCEL = f"{SRT_MOBILE}/ard/selectListArd02045_n.do"
 
 DEFAULT_HEADERS = {
-    "User-Agent": "Mozilla/5.0 (Linux; Android 5.1.1; LGM-V300K Build/N2G47H) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/39.0.0.0 Mobile Safari/537.36SRT-APP-Android V.1.0.6",
+    "User-Agent": (
+        "Mozilla/5.0 (Linux; Android 5.1.1; LGM-V300K Build/N2G47H) AppleWebKit/537.36 "
+        "(KHTML, like Gecko) Version/4.0 Chrome/39.0.0.0 Mobile Safari/537.36SRT-APP-Android V.1.0.6"
+    ),
     "Accept": "application/json",
 }
 
-DEFAULT_COOKIES = {}
-
 RESULT_SUCCESS = "SUCC"
 RESULT_FAIL = "FAIL"
 
@@ -56,7 +59,6 @@ class SRT:
     def __init__(self, srt_id, srt_pw, auto_login=True, verbose=False):
         self._session = requests.session()
         self._session.headers.update(DEFAULT_HEADERS)
-        self._session.cookies.update(DEFAULT_COOKIES)
 
         self.srt_id = srt_id
         self.srt_pw = srt_pw
@@ -100,7 +102,7 @@ class SRT:
             login_type = LOGIN_TYPES["EMAIL"]
         elif PHONE_NUMBER_REGEX.match(srt_id):
             login_type = LOGIN_TYPES["PHONE_NUMBER"]
-            srt_id = re.sub("-", "", srt_id)  # hypen is not sent
+            srt_id = re.sub("-", "", srt_id)  # hyphen is not sent
         else:
             login_type = LOGIN_TYPES["MEMBERSHIP_ID"]
 
@@ -187,9 +189,9 @@ class SRT:
             raise SRTNotLoggedInError()
 
         if dep not in STATION_CODE:
-            raise ValueError('Station "{}" not exists'.format(dep))
+            raise ValueError(f'Station "{dep}" not exists')
         if arr not in STATION_CODE:
-            raise ValueError('Station "{}" not exists'.format(arr))
+            raise ValueError(f'Station "{arr}" not exists')
 
         dep_code = STATION_CODE[dep]
         arr_code = STATION_CODE[arr]
@@ -232,7 +234,7 @@ class SRT:
         trains = [SRTTrain(train) for train in all_trains]
 
         # Note: updated api returns subarray of all trains,
-        #       therefore, to retreive all trains, retry unless there are no more trains
+        #       therefore, to retrieve all trains, retry unless there are no more trains
         while trains:
             last_dep_time = datetime.strptime(trains[-1].dep_time, "%H%M%S")
             next_dep_time = last_dep_time + timedelta(seconds=1)
@@ -281,7 +283,7 @@ class SRT:
 
         if train.train_name != "SRT":
             raise ValueError(
-                '"SRT" expected for a train name, {} given'.format(train.train_name)
+                f'"SRT" expected for a train name, {train.train_name} given'
             )
 
         if passengers is None:
@@ -317,11 +319,8 @@ class SRT:
         r = self._session.post(url=url, data=data)
         parser = SRTResponseData(r.text)
 
-        dup_msg = "요청하신 승차권과 동일한 시간대에 예약 또는 발권하신 승차권이 존재합니다."
         if not parser.success():
             raise SRTResponseError(parser.message())
-        elif dup_msg in parser.message():
-            raise SRTDuplicateError(parser.message())
 
         self._log(parser.message())
         reservation_result = parser.get_all()["reservListMap"][0]
